# © 2020 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import models


class AccountBankingMandate(models.Model):
    _inherit = "account.banking.mandate"

    # ------------------------------------------------------
    # Button functions
    # ------------------------------------------------------
    def set_bordereau_mandate(self):
        return {
            "name": "Affectation du nouveau mandat",
            "type": "ir.actions.act_window",
            "res_model": "account.banking.mandate.change.bordereau.wizard",
            "views": [[False, "form"]],
            "target": "new",
        }

    # ------------------------------------------------------
    # Business functions
    # ------------------------------------------------------
    def _select_open_bordereau(self):
        self.ensure_one()
        bordereau_ids = self.env["scop.bordereau"].search(
            [
                ("partner_id", "=", self.partner_id.id),
                ("state", "not in", ("paid", "cancel")),
            ]
        )
        return bordereau_ids

    def _change_bordereau_mandate(self, bordereau):
        """
        Affecte le mandat courant pur le bordereau passé en paramètre
        et les factures associées
        :param bordereau : objet scop.bordereau
        """
        payment_mode = self.env["account.payment.mode"].search(
            [("payment_method_id.code", "=", "sepa_direct_debit")]
        )
        bordereau.update(
            {
                "payment_mode_id": payment_mode.id,
            }
        )
        invoice_ids = bordereau.invoice_ids.filtered(
            lambda i: i.state in ("draft", "posted")
            and i.payment_state in ("draft", "not_paid", "partial")
        )
        for invoice in invoice_ids:
            self._change_invoice_mandate(invoice)
